==> anwiba-commons-http-1.0.76-sources.jar: net/anwiba/commons/http/ConvertingHttpRequestExecutorBuilder.java <==
/*
 * #%L
 *
 * %%
 * Copyright (C) 2007 - 2017 Andreas W. Bartels (bartels@anwiba.de)
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.http;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.apache.http.impl.conn.BasicHttpClientConnectionManager;

public class ConvertingHttpRequestExecutorBuilder implements IConvertingHttpRequestExecutorBuilder {

  final List<IApplicableHttpResponseExceptionFactory> applicableHttpResponseExceptionFactories = new ArrayList<>();
  private IHttpClientConnectionManagerProvider connectionManagerProvider;

  @Override
  public IConvertingHttpRequestExecutorBuilder setConnectionManagerProvider(
      final IHttpClientConnectionManagerProvider connectionManagerProvider) {
    this.connectionManagerProvider = connectionManagerProvider;
    return this;
  }

  @Override
  @SuppressWarnings("resource")
  public IConvertingHttpRequestExecutorBuilder useAlwaysTheSameConnection() {
    this.connectionManagerProvider = new HttpClientConnectionManagerProvider(new BasicHttpClientConnectionManager());
    return this;
  }

  @Override
  public IConvertingHttpRequestExecutorBuilder useAlwaysANewConnection() {
    this.connectionManagerProvider = new HttpClientConnectionManagerProvider();
    return this;
  }

  @Override
  public IConvertingHttpRequestExecutor build() {

    final IHttpClientConnectionManagerProvider provider = Optional
        .ofNullable(this.connectionManagerProvider)
        .orElseGet(() -> new HttpClientConnectionManagerProvider());

    final IHttpRequestExecutor executor = new HttpRequestExcecutorFactory(provider).create();
    return new ConvertingHttpRequestExecutor(executor);
  }

}

==> anwiba-commons-http-1.0.126-sources.jar: net/anwiba/commons/http/ConvertingHttpRequestExecutorBuilder.java <==
/*
 * #%L
 *
 * %%
 * Copyright (C) 2007 - 2017 Andreas W. Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.http;

public class ConvertingHttpRequestExecutorBuilder implements IConvertingHttpRequestExecutorBuilder {

  IHttpRequestExecutorFactoryBuilder builder = new HttpRequestExecutorFactoryBuilder();

  @Override
  public IConvertingHttpRequestExecutorBuilder useAlwaysTheSameConnection() {
    this.builder.useAlwaysTheSameConnection();
    return this;
  }

  @Override
  public IConvertingHttpRequestExecutorBuilder useAlwaysANewConnection() {
    this.builder.useAlwaysANewConnection();
    return this;
  }

  @Override
  public IConvertingHttpRequestExecutorBuilder usePoolingConnection() {
    return this;
  }

  @Override
  public IConvertingHttpRequestExecutor build() {
    final IHttpRequestExecutor executor = this.builder.build().create();
    return new ConvertingHttpRequestExecutor(executor);
  }

}
